<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation> justo ahora</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 رسالة جديدة</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 دقيقة مضت</translation>
    </message>
</context>
</TS>